==> wxwidgets_3.3.2-60_x86-mingw-static.zip: installed/x86-mingw-static/share/wxwidgets/wxWidgetsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "wx::wxbase" for configuration "Release"
set_property(TARGET wx::wxbase APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxbase PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C;CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_baseu-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxbase )
list(APPEND _cmake_import_check_files_for_wx::wxbase "${_IMPORT_PREFIX}/lib/libwx_baseu-3.3.a" )

# Import target "wx::wxnet" for configuration "Release"
set_property(TARGET wx::wxnet APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxnet PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_baseu_net-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxnet )
list(APPEND _cmake_import_check_files_for_wx::wxnet "${_IMPORT_PREFIX}/lib/libwx_baseu_net-3.3.a" )

# Import target "wx::wxcore" for configuration "Release"
set_property(TARGET wx::wxcore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxcore PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_mswu_core-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxcore )
list(APPEND _cmake_import_check_files_for_wx::wxcore "${_IMPORT_PREFIX}/lib/libwx_mswu_core-3.3.a" )

# Import target "wx::wxadv" for configuration "Release"
set_property(TARGET wx::wxadv APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxadv PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_mswu_adv-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxadv )
list(APPEND _cmake_import_check_files_for_wx::wxadv "${_IMPORT_PREFIX}/lib/libwx_mswu_adv-3.3.a" )

# Import target "wx::wxaui" for configuration "Release"
set_property(TARGET wx::wxaui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxaui PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_mswu_aui-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxaui )
list(APPEND _cmake_import_check_files_for_wx::wxaui "${_IMPORT_PREFIX}/lib/libwx_mswu_aui-3.3.a" )

# Import target "wx::wxhtml" for configuration "Release"
set_property(TARGET wx::wxhtml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxhtml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_mswu_html-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxhtml )
list(APPEND _cmake_import_check_files_for_wx::wxhtml "${_IMPORT_PREFIX}/lib/libwx_mswu_html-3.3.a" )

# Import target "wx::wxpropgrid" for configuration "Release"
set_property(TARGET wx::wxpropgrid APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxpropgrid PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_mswu_propgrid-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxpropgrid )
list(APPEND _cmake_import_check_files_for_wx::wxpropgrid "${_IMPORT_PREFIX}/lib/libwx_mswu_propgrid-3.3.a" )

# Import target "wx::wxribbon" for configuration "Release"
set_property(TARGET wx::wxribbon APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxribbon PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_mswu_ribbon-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxribbon )
list(APPEND _cmake_import_check_files_for_wx::wxribbon "${_IMPORT_PREFIX}/lib/libwx_mswu_ribbon-3.3.a" )

# Import target "wx::wxrichtext" for configuration "Release"
set_property(TARGET wx::wxrichtext APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxrichtext PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_mswu_richtext-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxrichtext )
list(APPEND _cmake_import_check_files_for_wx::wxrichtext "${_IMPORT_PREFIX}/lib/libwx_mswu_richtext-3.3.a" )

# Import target "wx::wxwebview" for configuration "Release"
set_property(TARGET wx::wxwebview APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxwebview PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_mswu_webview-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxwebview )
list(APPEND _cmake_import_check_files_for_wx::wxwebview "${_IMPORT_PREFIX}/lib/libwx_mswu_webview-3.3.a" )

# Import target "wx::wxscintilla" for configuration "Release"
set_property(TARGET wx::wxscintilla APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxscintilla PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwxscintilla-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxscintilla )
list(APPEND _cmake_import_check_files_for_wx::wxscintilla "${_IMPORT_PREFIX}/lib/libwxscintilla-3.3.a" )

# Import target "wx::wxlexilla" for configuration "Release"
set_property(TARGET wx::wxlexilla APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxlexilla PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwxlexilla-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxlexilla )
list(APPEND _cmake_import_check_files_for_wx::wxlexilla "${_IMPORT_PREFIX}/lib/libwxlexilla-3.3.a" )

# Import target "wx::wxstc" for configuration "Release"
set_property(TARGET wx::wxstc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxstc PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_mswu_stc-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxstc )
list(APPEND _cmake_import_check_files_for_wx::wxstc "${_IMPORT_PREFIX}/lib/libwx_mswu_stc-3.3.a" )

# Import target "wx::wxxrc" for configuration "Release"
set_property(TARGET wx::wxxrc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxxrc PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_mswu_xrc-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxxrc )
list(APPEND _cmake_import_check_files_for_wx::wxxrc "${_IMPORT_PREFIX}/lib/libwx_mswu_xrc-3.3.a" )

# Import target "wx::wxgl" for configuration "Release"
set_property(TARGET wx::wxgl APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxgl PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_mswu_gl-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxgl )
list(APPEND _cmake_import_check_files_for_wx::wxgl "${_IMPORT_PREFIX}/lib/libwx_mswu_gl-3.3.a" )

# Import target "wx::wxqa" for configuration "Release"
set_property(TARGET wx::wxqa APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxqa PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_mswu_qa-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxqa )
list(APPEND _cmake_import_check_files_for_wx::wxqa "${_IMPORT_PREFIX}/lib/libwx_mswu_qa-3.3.a" )

# Import target "wx::wxxml" for configuration "Release"
set_property(TARGET wx::wxxml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxxml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libwx_baseu_xml-3.3.a"
  )

list(APPEND _cmake_import_check_targets wx::wxxml )
list(APPEND _cmake_import_check_files_for_wx::wxxml "${_IMPORT_PREFIX}/lib/libwx_baseu_xml-3.3.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> wxwidgets_3.3.2-71-r5_x86-mingw-static.zip: installed/x86-mingw-static/share/wxwidgets/wxWidgetsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "wx::wxbase" for configuration "Release"
set_property(TARGET wx::wxbase APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxbase PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C;CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxbase33u.a"
  )

list(APPEND _cmake_import_check_targets wx::wxbase )
list(APPEND _cmake_import_check_files_for_wx::wxbase "${_IMPORT_PREFIX}/lib/wxbase33u.a" )

# Import target "wx::wxnet" for configuration "Release"
set_property(TARGET wx::wxnet APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxnet PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxbase33u_net.a"
  )

list(APPEND _cmake_import_check_targets wx::wxnet )
list(APPEND _cmake_import_check_files_for_wx::wxnet "${_IMPORT_PREFIX}/lib/wxbase33u_net.a" )

# Import target "wx::wxcore" for configuration "Release"
set_property(TARGET wx::wxcore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxcore PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxmsw33u_core.a"
  )

list(APPEND _cmake_import_check_targets wx::wxcore )
list(APPEND _cmake_import_check_files_for_wx::wxcore "${_IMPORT_PREFIX}/lib/wxmsw33u_core.a" )

# Import target "wx::wxadv" for configuration "Release"
set_property(TARGET wx::wxadv APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxadv PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxmsw33u_adv.a"
  )

list(APPEND _cmake_import_check_targets wx::wxadv )
list(APPEND _cmake_import_check_files_for_wx::wxadv "${_IMPORT_PREFIX}/lib/wxmsw33u_adv.a" )

# Import target "wx::wxaui" for configuration "Release"
set_property(TARGET wx::wxaui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxaui PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxmsw33u_aui.a"
  )

list(APPEND _cmake_import_check_targets wx::wxaui )
list(APPEND _cmake_import_check_files_for_wx::wxaui "${_IMPORT_PREFIX}/lib/wxmsw33u_aui.a" )

# Import target "wx::wxhtml" for configuration "Release"
set_property(TARGET wx::wxhtml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxhtml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxmsw33u_html.a"
  )

list(APPEND _cmake_import_check_targets wx::wxhtml )
list(APPEND _cmake_import_check_files_for_wx::wxhtml "${_IMPORT_PREFIX}/lib/wxmsw33u_html.a" )

# Import target "wx::wxpropgrid" for configuration "Release"
set_property(TARGET wx::wxpropgrid APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxpropgrid PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxmsw33u_propgrid.a"
  )

list(APPEND _cmake_import_check_targets wx::wxpropgrid )
list(APPEND _cmake_import_check_files_for_wx::wxpropgrid "${_IMPORT_PREFIX}/lib/wxmsw33u_propgrid.a" )

# Import target "wx::wxribbon" for configuration "Release"
set_property(TARGET wx::wxribbon APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxribbon PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxmsw33u_ribbon.a"
  )

list(APPEND _cmake_import_check_targets wx::wxribbon )
list(APPEND _cmake_import_check_files_for_wx::wxribbon "${_IMPORT_PREFIX}/lib/wxmsw33u_ribbon.a" )

# Import target "wx::wxrichtext" for configuration "Release"
set_property(TARGET wx::wxrichtext APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxrichtext PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxmsw33u_richtext.a"
  )

list(APPEND _cmake_import_check_targets wx::wxrichtext )
list(APPEND _cmake_import_check_files_for_wx::wxrichtext "${_IMPORT_PREFIX}/lib/wxmsw33u_richtext.a" )

# Import target "wx::wxscintilla" for configuration "Release"
set_property(TARGET wx::wxscintilla APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxscintilla PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxscintilla.a"
  )

list(APPEND _cmake_import_check_targets wx::wxscintilla )
list(APPEND _cmake_import_check_files_for_wx::wxscintilla "${_IMPORT_PREFIX}/lib/wxscintilla.a" )

# Import target "wx::wxlexilla" for configuration "Release"
set_property(TARGET wx::wxlexilla APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxlexilla PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxlexilla.a"
  )

list(APPEND _cmake_import_check_targets wx::wxlexilla )
list(APPEND _cmake_import_check_files_for_wx::wxlexilla "${_IMPORT_PREFIX}/lib/wxlexilla.a" )

# Import target "wx::wxstc" for configuration "Release"
set_property(TARGET wx::wxstc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxstc PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxmsw33u_stc.a"
  )

list(APPEND _cmake_import_check_targets wx::wxstc )
list(APPEND _cmake_import_check_files_for_wx::wxstc "${_IMPORT_PREFIX}/lib/wxmsw33u_stc.a" )

# Import target "wx::wxxrc" for configuration "Release"
set_property(TARGET wx::wxxrc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxxrc PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxmsw33u_xrc.a"
  )

list(APPEND _cmake_import_check_targets wx::wxxrc )
list(APPEND _cmake_import_check_files_for_wx::wxxrc "${_IMPORT_PREFIX}/lib/wxmsw33u_xrc.a" )

# Import target "wx::wxgl" for configuration "Release"
set_property(TARGET wx::wxgl APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxgl PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxmsw33u_gl.a"
  )

list(APPEND _cmake_import_check_targets wx::wxgl )
list(APPEND _cmake_import_check_files_for_wx::wxgl "${_IMPORT_PREFIX}/lib/wxmsw33u_gl.a" )

# Import target "wx::wxqa" for configuration "Release"
set_property(TARGET wx::wxqa APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxqa PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxmsw33u_qa.a"
  )

list(APPEND _cmake_import_check_targets wx::wxqa )
list(APPEND _cmake_import_check_files_for_wx::wxqa "${_IMPORT_PREFIX}/lib/wxmsw33u_qa.a" )

# Import target "wx::wxxml" for configuration "Release"
set_property(TARGET wx::wxxml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(wx::wxxml PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/wxbase33u_xml.a"
  )

list(APPEND _cmake_import_check_targets wx::wxxml )
list(APPEND _cmake_import_check_files_for_wx::wxxml "${_IMPORT_PREFIX}/lib/wxbase33u_xml.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
